@@ -18,7 +18,7 @@ import urllib.parse
 import uuid
 from functools import cache
 from plistlib import load as plistload
-from typing import Callable, List, Optional, Tuple, TypeVar, Union
+from typing import TYPE_CHECKING, Callable, List, Optional, Tuple, TypeVar, Union
 from uuid import UUID
 
 import requests
@@ -28,6 +28,9 @@ import osxphotos.tempdir as tempdir
 from osxphotos.platform import get_macos_version, is_macos
 from osxphotos.unicode import normalize_fs_path
 
+if TYPE_CHECKING:
+    from osxphotos.photoinfo import PhotoInfo
+
 T = TypeVar("T", bound=Union[str, pathlib.Path])
 
 logger = logging.getLogger("osxphotos")
